@@ -31,10 +31,14 @@ import json
 import glob
 import logging
 import functools
+import posixpath
+import stat
 
 from pkg_resources import parse_version
 
 from .modules import MODULES
+from .modules.module_error import ModuleError
+from .modules.vpcs import VPCS
 from .version import __version__
 from .qt import QtGui, QtCore, QtNetwork
 from .servers import Servers
@@ -57,12 +61,13 @@ from .items.link_item import LinkItem
 from .items.shape_item import ShapeItem
 from .items.image_item import ImageItem
 from .items.note_item import NoteItem
-from .topology import Topology, TopologyInstance
-from .cloud.utils import UploadProjectThread
+from .topology import Topology
+from .cloud.utils import UploadProjectThread, UploadFilesThread, ssh_client, DownloadImagesThread, DeleteInstanceThread
 from .cloud.rackspace_ctrl import get_provider
 from .cloud.exceptions import KeyPairExists
 from .cloud_instances import CloudInstances
 
+
 log = logging.getLogger(__name__)
 
 CLOUD_SETTINGS_GROUP = "Cloud"
@@ -78,10 +83,6 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
     # signal to tell the view if the user is adding a link or not
     adding_link_signal = QtCore.Signal(bool)
 
-    # for application reboot
-    reboot_signal = QtCore.Signal()
-    exit_code_reboot = -123456789
-
     # signal to tell a project was closed
     project_about_to_close_signal = QtCore.pyqtSignal(str)
     # signal to tell a new project was created
@@ -103,6 +104,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         self._max_recent_files = 5
         self._recent_file_actions = []
         self._start_time = time.time()
+        self.loading_cloud_project = False
 
         self._project_settings = {
             "project_name": "unsaved",
@@ -111,12 +113,14 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
             "project_type": "local",
         }
 
-        try:
-            from .news_dock_widget import NewsDockWidget
-            self._uiNewsDockWidget = NewsDockWidget(self)
-            self.addDockWidget(QtCore.Qt.DockWidgetArea(QtCore.Qt.RightDockWidgetArea), self._uiNewsDockWidget)
-        except ImportError:
-            self._uiNewsDockWidget = None
+        self._uiNewsDockWidget = None
+        if not self._settings["hide_news_dock_widget"]:
+            try:
+                from .news_dock_widget import NewsDockWidget
+                self._uiNewsDockWidget = NewsDockWidget(self)
+                self.addDockWidget(QtCore.Qt.DockWidgetArea(QtCore.Qt.BottomDockWidgetArea), self._uiNewsDockWidget)
+            except ImportError:
+                pass
 
         # restore the geometry and state of the main window.
         settings = QtCore.QSettings()
@@ -125,7 +129,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
         # do not show the nodes dock widget my default
         if not ENABLE_CLOUD:
-            self.uiNodesDockWidget.setVisible(False)
+            self.uiCloudInspectorDockWidget.close()
 
         # populate the view -> docks menu
         self.uiDocksMenu.addAction(self.uiTopologySummaryDockWidget.toggleViewAction())
@@ -265,16 +269,15 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         Connect widgets to slots
         """
 
-        # to reboot
-        self.reboot_signal.connect(self.rebootSlot)
-
         # file menu connections
         self.uiNewProjectAction.triggered.connect(self._newProjectActionSlot)
         self.uiOpenProjectAction.triggered.connect(self.openProjectActionSlot)
         self.uiSaveProjectAction.triggered.connect(self._saveProjectActionSlot)
         self.uiSaveProjectAsAction.triggered.connect(self._saveProjectAsActionSlot)
         self.uiExportProjectAction.triggered.connect(self._exportProjectActionSlot)
-        #self.uiImportProjectAction.triggered.connect(self._importProjectActionSlot)
+        self.uiImportProjectAction.triggered.connect(self._importProjectActionSlot)
+        self.uiMoveLocalProjectToCloudAction.triggered.connect(self._moveLocalProjectToCloudActionSlot)
+        self.uiMoveCloudProjectToLocalAction.triggered.connect(self._moveCloudProjectToLocalActionSlot)
         self.uiImportExportConfigsAction.triggered.connect(self._importExportConfigsActionSlot)
         self.uiScreenshotAction.triggered.connect(self._screenshotActionSlot)
         self.uiSnapshotAction.triggered.connect(self._snapshotActionSlot)
@@ -306,6 +309,9 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         # device menu is contextual and is build on-the-fly
         self.uiDeviceMenu.aboutToShow.connect(self._deviceMenuActionSlot)
 
+        # tools menu connections
+        self.uiVPCSAction.triggered.connect(self._vpcsActionSlot)
+
         # annotate menu connections
         self.uiAddNoteAction.triggered.connect(self._addNoteActionSlot)
         self.uiInsertImageAction.triggered.connect(self._insertImageActionSlot)
@@ -376,7 +382,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
     def _createNewProject(self, new_project_settings):
         """
-        Crates a new project.
+        Creates a new project.
 
         :param new_project_settings: project settings (dict)
         """
@@ -388,7 +394,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         except FileExistsError:
             pass
         except OSError as e:
-            QtGui.QMessageBox.critical(self, "New project", "Could not create project files directory {}: {}".format(new_project_settings["project_files_dir"]), str(e))
+            QtGui.QMessageBox.critical(self, "New project", "Could not create project files directory {}: {}".format(new_project_settings["project_files_dir"], e))
             return
 
         # let all modules know about the new project files directory
@@ -410,6 +416,10 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
             project_dialog = NewProjectDialog(self)
             project_dialog.show()
             create_new_project = project_dialog.exec_()
+            # Close the device dock so it repopulates.  Done in case switching
+            # between cloud and local.
+            self.uiNodesDockWidget.setVisible(False)
+            self.uiNodesDockWidget.setWindowTitle("")
 
             self.project_about_to_close_signal.emit(self._project_settings["project_path"])
 
@@ -716,8 +726,13 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         Slot called when connecting to all the nodes using the AUX console.
         """
 
-        #TODO: connect to AUX consoles
-        pass
+        delay = self._settings["delay_console_all"]
+        counter = 0
+        for item in self.uiGraphicsView.scene().items():
+            if isinstance(item, NodeItem) and hasattr(item.node(), "auxConsole") and item.node().initialized() and item.node().status() == Node.started:
+                callback = functools.partial(self.uiGraphicsView.consoleToNode, item.node(), aux=True)
+                QtCore.QTimer.singleShot(counter, callback)
+                counter += delay
 
     def _consoleAllActionSlot(self):
         """
@@ -732,6 +747,33 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
                 QtCore.QTimer.singleShot(counter, callback)
                 counter += delay
 
+    def _vpcsActionSlot(self):
+        """
+        Slot called when VPCS multi-host is clicked in the Tools menu.
+        """
+
+        vpcs_module = VPCS.instance()
+        try:
+            working_dir = os.path.join(self._project_settings["project_files_dir"], "vpcs", "multi-host")
+            os.makedirs(working_dir)
+        except FileExistsError:
+            pass
+        except OSError as e:
+            QtGui.QMessageBox.critical(self, "VPCS", "Could not create the VPCS working directory: {}".format(e))
+            return
+
+        try:
+            vpcs_port = vpcs_module.startMultiHostVPCS(working_dir)
+        except ModuleError as e:
+            QtGui.QMessageBox.critical(self, "VPCS", "{}".format(e))
+            return
+
+        try:
+            from .telnet_console import telnetConsole
+            telnetConsole("VPCS multi-host", "127.0.0.1", vpcs_port)
+        except (OSError, ValueError) as e:
+            QtGui.QMessageBox.critical(self, "Console", "Cannot start console application: {}".format(e))
+
     def _addNoteActionSlot(self):
         """
         Slot called when adding a new note on the scene.
@@ -903,7 +945,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
             self.uiNodesDockWidget.setWindowTitle(title)
             self.uiNodesDockWidget.setVisible(True)
             self.uiNodesView.clear()
-            self.uiNodesView.populateNodesView(category)
+            self.uiNodesView.populateNodesView(category, self._project_settings["project_type"])
 
     def _browseRoutersActionSlot(self):
         """
@@ -985,6 +1027,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
         if self.checkForUnsavedChanges():
             self.project_about_to_close_signal.emit(self._project_settings["project_path"])
+            VPCS.instance().stopMultiHostVPCS()
 
             # save the geometry and state of the main window.
             settings = QtCore.QSettings()
@@ -1003,13 +1046,6 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         else:
             event.ignore()
 
-    def rebootSlot(self):
-        """
-        Slot to receive the reboot signal.
-        """
-
-        QtGui.QApplication.exit(self.exit_code_reboot)
-
     def checkForUnsavedChanges(self):
         """
         Checks if there are any unsaved changes.
@@ -1030,6 +1066,19 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
                 return self.saveProject(self._project_settings["project_path"])
             elif reply == QtGui.QMessageBox.Cancel:
                 return False
+        else:
+            # check if any node is running
+            topology = Topology.instance()
+            running_node = False
+            for node in topology.nodes():
+                if hasattr(node, "start") and node.status() == Node.started:
+                    running_node = True
+                    break
+            if running_node:
+                reply = QtGui.QMessageBox.warning(self, "GNS3", "A device is still running, would you like to continue?",
+                                                  QtGui.QMessageBox.Yes | QtGui.QMessageBox.No)
+                if reply == QtGui.QMessageBox.No:
+                    return False
         self._deleteTemporaryProject()
         return True
 
@@ -1038,8 +1087,12 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         Called by QTimer.singleShot to load everything needed at startup.
         """
 
+        if self._settings["debug_level"]:
+            root = logging.getLogger()
+            root.addHandler(logging.StreamHandler(sys.stdout))
+
         if self._uiNewsDockWidget and not self._uiNewsDockWidget.isVisible():
-            self.addDockWidget(QtCore.Qt.DockWidgetArea(QtCore.Qt.RightDockWidgetArea), self._uiNewsDockWidget)
+            self.addDockWidget(QtCore.Qt.DockWidgetArea(QtCore.Qt.BottomDockWidgetArea), self._uiNewsDockWidget)
 
         self._gettingStartedActionSlot(auto=True)
 
@@ -1054,7 +1107,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
                 with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
                     sock.bind((server.host, 0))
             except OSError as e:
-                QtGui.QMessageBox.critical(self, "Local server", "Could not bind with {host}: {error} (please check your host binding setting)".format(host=server.host, error=e))
+                QtGui.QMessageBox.critical(self, "Local server", "Could not bind with {host}: {error} (please check your host binding setting in the preferences)".format(host=server.host, error=e))
                 return
 
             try:
@@ -1066,7 +1119,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
                     # not a normal OSError, thrown from the Websocket client.
                     MessageBox(self, "Local server", "Something other than a GNS3 server is already running on {} port {}, please adjust the local server port setting".format(server.host,
                                                                                                                                                                                server.port),
-                                                                                                                                                                               str(e))
+                                                                                                                                                                               e)
                     return
 
                 if not servers.localServerAutoStart():
@@ -1161,7 +1214,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         except FileExistsError:
             pass
         except OSError as e:
-            QtGui.QMessageBox.critical(self, "Save project", "Could not create the projects directory {}: {}".format(projects_dir_path, str(e)))
+            QtGui.QMessageBox.critical(self, "Save project", "Could not create the projects directory {}: {}".format(projects_dir_path, e))
             return
 
         file_dialog = QtGui.QFileDialog(self)
@@ -1187,7 +1240,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         except FileExistsError:
             pass
         except OSError as e:
-            QtGui.QMessageBox.critical(self, "Save project", "Could not create project directory {}: {}".format(new_project_files_dir), str(e))
+            QtGui.QMessageBox.critical(self, "Save project", "Could not create project directory {}: {}".format(new_project_files_dir), e)
             return
 
         # create the sub-directories to avoid race conditions when setting the new working
@@ -1201,7 +1254,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
                 except FileExistsError:
                     pass
                 except OSError as e:
-                    QtGui.QMessageBox.critical(self, "Save project", "Could not create project sub-directory {}: {}".format(destination_dir, str(e)))
+                    QtGui.QMessageBox.critical(self, "Save project", "Could not create project sub-directory {}: {}".format(destination_dir, e))
                     return
 
         # let all modules know about the new project files directory
@@ -1246,6 +1299,8 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
             QtGui.QMessageBox.critical(self, "Save", "Could not save project to {}: {}".format(path, e))
             return False
 
+        if not self._temporary_project:
+            self._createScreenshot(os.path.join(os.path.dirname(path), "screenshot.png"))
         self.uiStatusBar.showMessage("Project saved to {}".format(path), 2000)
         self._project_settings["project_path"] = path
         self._setCurrentFile(path)
@@ -1316,7 +1371,6 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
             QtGui.QApplication.setOverrideCursor(QtCore.Qt.WaitCursor)
             with open(path, "r") as f:
-                need_to_save = False
                 log.info("loading project: {}".format(path))
                 json_topology = json.load(f)
 
@@ -1337,34 +1391,14 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
                 self.uiGraphicsView.updateProjectFilesDir(self._project_settings["project_files_dir"])
 
-                # if we're opening a cloud project, fire up instances
+                # if we're opening a cloud project, defer topology load operations
                 if json_topology["resources_type"] == "cloud":
                     self._project_settings["project_type"] = "cloud"
-                    # new_instances = []
-                    # for instance in json_topology["topology"]["instances"]:
-                    #     name = instance["name"]
-                    #     flavor = instance["size_id"]
-                    #     image = instance["image_id"]
-                    #     i, k = self._create_instance(name, flavor, image)
-                    #     new_instances.append({
-                    #         "name": i.name,
-                    #         "id": i.id,
-                    #         "size_id": flavor,
-                    #         "image_id": image,
-                    #         "private_key": k.private_key,
-                    #         "public_key": k.public_key
-                    #     })
-                    # # update topology with new image data
-                    # json_topology["topology"]["instances"] = new_instances
-                    # # we need to save the updates
-                    # need_to_save = True
+                    self.loading_cloud_project = True
                 else:
                     self._project_settings["project_type"] = "local"
+                    topology.load(json_topology)
 
-                topology.load(json_topology)
-
-                if need_to_save:
-                    self.saveProject(path)
         except OSError as e:
             QtGui.QMessageBox.critical(self, "Load", "Could not load project {}: {}".format(os.path.basename(path), e))
             #log.error("exception {type}".format(type=type(e)), exc_info=1)
@@ -1576,7 +1610,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
                 return
 
             project_instances = json_topology["topology"]["instances"]
-            self.CloudInspectorView.load(self, project_instances)
+            self.CloudInspectorView.load(self, [i["id"] for i in project_instances])
 
     def add_instance_to_project(self, instance, keypair):
         """
@@ -1596,7 +1630,8 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         self.CloudInspectorView.addInstance(instance)
 
         # persist infos saving current project
-        self.saveProject(self._project_settings["project_path"])
+        if not self.loading_cloud_project:
+            self.saveProject(self._project_settings["project_path"])
 
     def remove_instance_from_project(self, instance):
         """
@@ -1636,9 +1671,13 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         if self._temporary_project:
             # do nothing if project is temporary
             QtGui.QMessageBox.critical(
-                self, "Export project server",
-                "Cannot export temporary projects, please save current project first.")
+                self,
+                "Backup project",
+                "Cannot backup temporary projects, please save current project first."
+            )
             return
+        if self.checkForUnsavedChanges():
+            self.saveProject(self._project_settings["project_path"])
 
         upload_thread = UploadProjectThread(
             self,
@@ -1646,7 +1685,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
             self._project_settings['project_path'],
             self._settings['images_path']
         )
-        progress_dialog = ProgressDialog(upload_thread, "Exporting Project", "Uploading project files...", "Cancel",
+        progress_dialog = ProgressDialog(upload_thread, "Backing Up Project", "Uploading project files...", "Cancel",
                                          parent=self)
         progress_dialog.show()
         progress_dialog.exec_()
@@ -1662,6 +1701,209 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         dialog.show()
         dialog.exec_()
 
+    def _moveLocalProjectToCloudActionSlot(self):
+        if self._temporary_project:
+            # do nothing if project is temporary
+            QtGui.QMessageBox.critical(
+                self,
+                "Move project to Cloud",
+                "Cannot move temporary projects, please save current project first.")
+            return
+        if self._project_settings["project_type"] == "cloud":
+            # do nothing if project is already a cloud project
+            QtGui.QMessageBox.critical(
+                self,
+                "Move project to Cloud",
+                "This project is already a Cloud Project")
+            return
+        if not self.checkForUnsavedChanges():
+            # do nothing if project is already a cloud project
+            QtGui.QMessageBox.critical(
+                self,
+                "Unsaved changes",
+                "There are unsaved changes. Please save the project first.")
+            return
+
+        # Upload images to cloud storage
+        topology = Topology.instance()
+        images = set([
+            (
+                node.settings()['image'],
+                'images/' + os.path.relpath(node.settings()['image'], self._settings["images_path"])
+            )
+            for node in topology.nodes() if 'image' in node.settings()
+        ])
+        log.debug('uploading images ' + str(images) + ' to cloud')
+        upload_thread = UploadFilesThread(self, self._cloud_settings, images)
+        upload_images_progress_dialog = ProgressDialog(upload_thread, "Uploading images", "Uploading image files...",
+                                                       "Cancel", parent=self)
+        upload_images_progress_dialog.show()
+        upload_images_progress_dialog.exec_()
+
+        progress_dialog = QtGui.QProgressDialog("Moving project to cloud", "Cancel", 0, 100, self)
+        progress_dialog.show()
+
+        def buildComplete(server_id):
+            progress_dialog.setValue(80)
+            log.debug("websocket connected, server_id=" + str(server_id))
+
+            instance = topology.getInstance(server_id)
+            # copy nvram, config, and disk files to server
+            with ssh_client(instance.host, instance.private_key) as client:
+                log.debug('copying device files to cloud instance')
+                sftp = client.open_sftp()
+
+                project_files_dir = os.path.join(
+                    os.path.dirname(self._project_settings['project_path']),
+                    os.path.basename(os.path.dirname(self._project_settings['project_path'])) + '-files'
+                )
+                dest_project_path = posixpath.join(
+                    '/root/GNS3/projects',
+                    os.path.basename(os.path.dirname(self._project_settings['project_path']))
+                )
+
+                for root, dirs, files in os.walk(project_files_dir):
+                    directory = posixpath.normpath(posixpath.join(
+                        dest_project_path,
+                        os.path.relpath(root, project_files_dir).replace('\\', '/')
+                    ))
+                    sftp.mkdir(directory)
+                    sftp.chdir(directory)
+
+                    for file in files:
+                        local_filepath = os.path.join(root, file)
+                        if os.path.isfile(local_filepath) and not self._should_exclude_copying_file(file):
+                            log.debug('copying file ' + local_filepath)
+                            sftp.put(local_filepath, file)
+                            log.debug('copied file successfully')
+
+                sftp.close()
+
+            self._project_settings["project_type"] = "cloud"
+
+            # switch server on all nodes to cloud instance
+            server = Servers.instance().anyCloudServer()
+
+            for node in topology.nodes():
+                node._server = server
+
+            # reload project
+            self.saveProject(self._project_settings["project_path"])
+            topology.reset()
+            self.loadProject(self._project_settings["project_path"])
+            progress_dialog.accept()
+
+        instances = CloudInstances.instance().instances
+        for instance in instances:
+            topology.addInstance2(instance)
+        self.CloudInspectorView.load(self, [i.id for i in topology.instances()])
+
+        # Create a new instance.  At some point we could reuse an existing instance.
+        builder = self.CloudInspectorView.createInstance(
+            self._project_settings["project_name"],
+            self.cloudSettings()['default_flavor'],
+            self.cloudSettings()['default_image']
+        )
+        builder.buildComplete.connect(buildComplete)
+
+    def _moveCloudProjectToLocalActionSlot(self):
+        if self._temporary_project:
+            # do nothing if project is temporary
+            QtGui.QMessageBox.critical(
+                self,
+                "Move project to local machine",
+                "Cannot move temporary projects, please save current project first.")
+            return
+        if self._project_settings["project_type"] == "local":
+            # do nothing if project is already a cloud project
+            QtGui.QMessageBox.critical(
+                self,
+                "Move project to ",
+                "This project is already a local project")
+            return
+        if not self.checkForUnsavedChanges():
+            # do nothing if project is already a cloud project
+            QtGui.QMessageBox.critical(
+                self,
+                "Unsaved changes",
+                "There are unsaved changes. Please save the project first.")
+            return
+
+        topology = Topology.instance()
+
+        # download images from cloud storage
+        images = set(
+            [posixpath.basename(node.settings()["image"]) for node in topology.nodes() if 'image' in node.settings()]
+        )
+
+        log.debug('downloading images ' + str(images))
+        download_images_thread = DownloadImagesThread(self._cloud_settings, self._settings['images_path'], images)
+        download_images_progress_dialog = ProgressDialog(download_images_thread, "Downloading Images",
+                                                         "Downloading images files...", "Cancel", parent=self)
+        download_images_progress_dialog.show()
+        download_images_progress_dialog.exec_()
+
+        # copy device files from cloud instances
+        src_project_path = posixpath.join(
+            '/root/GNS3/projects',
+            os.path.basename(os.path.dirname(self._project_settings['project_path']))
+        )
+        project_files_dir = os.path.join(
+            os.path.dirname(self._project_settings['project_path']),
+            os.path.basename(os.path.dirname(self._project_settings['project_path'])) + '-files'
+        )
+
+        for topology_instance in topology.instances():
+            log.debug('copying device files from instance ' + str(topology_instance.host))
+            with ssh_client(topology_instance.host, topology_instance.private_key) as client:
+                if client is not None:
+                    sftp = client.open_sftp()
+
+                    def copy_files(src_dir, dest_dir):
+                        if not os.path.exists(dest_dir):
+                            os.makedirs(dest_dir)
+
+                        files = [f.filename for f in sftp.listdir_attr(src_dir) if stat.S_ISREG(f.st_mode)]
+                        for file in files:
+                            if not self._should_exclude_copying_file(file):
+                                src_filename = posixpath.join(src_dir, file)
+                                dest_filename = os.path.join(dest_dir, file)
+                                sftp.get(src_filename, dest_filename)
+
+                        dirs = [d.filename for d in sftp.listdir_attr(src_dir) if stat.S_ISDIR(d.st_mode)]
+                        for d in dirs:
+                            copy_files(posixpath.join(src_dir, d), os.path.join(dest_dir, d))
+
+                    copy_files(src_project_path, project_files_dir)
+
+                    sftp.close()
+                else:
+                    log.debug('could not connect to instance ' + str(topology_instance.host))
+
+        # switch server on all nodes to local server
+        server = Servers.instance().localServer()
+
+        for node in topology.nodes():
+            node._server = server
+            if "image" in node.settings():
+                node.settings()["image"] = os.path.basename(node.settings()["image"])
+
+        # reload project
+        self._project_settings["project_type"] = "local"
+        self.saveProject(self._project_settings["project_path"])
+        topology.reset()
+        self.loadProject(self._project_settings["project_path"])
+
+    @staticmethod
+    def _should_exclude_copying_file(filename):
+        """
+        Returns whether or not a file should be excluded from copying when converting projects
+        from cloud to local or vice versa
+        :param filename:
+        :return: True if file should be excluded, False otherwise
+        """
+        return filename.endswith('.ghost')
+
     def _cloud_instance_selected(self, instance_id):
         """
         Clear selection, then select all the nodes on the graphics view
