@@ -21,8 +21,6 @@ Configuration page for Dynamips IOS routers.
 
 import os
 import re
-import sys
-import pkg_resources
 
 from gns3.qt import QtCore, QtGui
 from gns3.dialogs.node_configurator_dialog import ConfigurationError
@@ -123,10 +121,7 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
         Slot to open a file browser and select a startup-config file.
         """
 
-        if hasattr(sys, "frozen"):
-            config_dir = "configs"
-        else:
-            config_dir = pkg_resources.resource_filename("gns3", "configs")
+        config_dir = os.path.join(os.path.dirname(QtCore.QSettings().fileName()), "base_configs")
         path = QtGui.QFileDialog.getOpenFileName(self, "Select a startup configuration", config_dir)
         if not path:
             return
@@ -143,10 +138,7 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
         Slot to open a file browser and select a private-config file.
         """
 
-        if hasattr(sys, "frozen"):
-            config_dir = "configs"
-        else:
-            config_dir = pkg_resources.resource_filename("gns3", "configs")
+        config_dir = os.path.join(os.path.dirname(QtCore.QSettings().fileName()), "base_configs")
         path = QtGui.QFileDialog.getOpenFileName(self, "Select a private configuration", config_dir)
         if not path:
             return
@@ -236,12 +228,6 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
                 self.uiAuxPortLabel.hide()
                 self.uiAuxPortSpinBox.hide()
 
-            # load the startup-config
-            self.uiStartupConfigLineEdit.setText(settings["startup_config"])
-
-            # load the private-config
-            self.uiPrivateConfigLineEdit.setText(settings["private_config"])
-
             # load the MAC address setting
             self.uiBaseMACLineEdit.setInputMask("HHHH.HHHH.HHHH;_")
 
@@ -261,12 +247,6 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
             self.uiIOSImageLabel.hide()
             self.uiIOSImageLineEdit.hide()
             self.uiIOSImageToolButton.hide()
-            self.uiStartupConfigLabel.hide()
-            self.uiStartupConfigLineEdit.hide()
-            self.uiStartupConfigToolButton.hide()
-            self.uiPrivateConfigLabel.hide()
-            self.uiPrivateConfigLineEdit.hide()
-            self.uiPrivateConfigToolButton.hide()
             self.uiConsolePortLabel.hide()
             self.uiConsolePortSpinBox.hide()
             self.uiAuxPortLabel.hide()
@@ -274,6 +254,19 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
             self.uiBaseMacLabel.hide()
             self.uiBaseMACLineEdit.hide()
 
+        if not node:
+            # load the startup-config
+            self.uiStartupConfigLineEdit.setText(settings["startup_config"])
+            # load the private-config
+            self.uiPrivateConfigLineEdit.setText(settings["private_config"])
+        else:
+            self.uiStartupConfigLabel.hide()
+            self.uiStartupConfigLineEdit.hide()
+            self.uiStartupConfigToolButton.hide()
+            self.uiPrivateConfigLabel.hide()
+            self.uiPrivateConfigLineEdit.hide()
+            self.uiPrivateConfigToolButton.hide()
+
         # show the platform and chassis if applicable
         platform = settings["platform"]
         self.uiPlatformTextLabel.setText(platform)
@@ -456,10 +449,7 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
             name = self.uiNameLineEdit.text()
             if not name:
                 QtGui.QMessageBox.critical(self, "Name", "IOS router name cannot be empty!")
-            elif node and not re.search(r"""^[\-\w]+$""", name):
-                # IOS names must start with a letter, end with a letter or digit, and
-                # have as interior characters only letters, digits, and hyphens.
-                # They must be 63 characters or fewer.
+            elif node and not node.validateHostname(name):
                 QtGui.QMessageBox.critical(self, "Name", "Invalid name detected for IOS router: {}".format(name))
             else:
                 settings["name"] = name
@@ -467,20 +457,6 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
             settings["console"] = self.uiConsolePortSpinBox.value()
             settings["aux"] = self.uiAuxPortSpinBox.value()
 
-            startup_config = self.uiStartupConfigLineEdit.text()
-            if startup_config != settings["startup_config"]:
-                if os.access(startup_config, os.R_OK):
-                    settings["startup_config"] = startup_config
-                else:
-                    QtGui.QMessageBox.critical(self, "Startup-config", "Cannot read the startup-config file")
-
-            private_config = self.uiPrivateConfigLineEdit.text()
-            if private_config != settings["private_config"]:
-                if os.access(private_config, os.R_OK):
-                    settings["private_config"] = private_config
-                else:
-                    QtGui.QMessageBox.critical(self, "Private-config", "Cannot read the private-config file")
-
             # check and save the base MAC address
             #mac = self.uiBaseMACLineEdit.text()
             #if mac and not re.search(r"""^([0-9a-fA-F]{4}\.){2}[0-9a-fA-F]{4}$""", mac):
@@ -502,6 +478,21 @@ class IOSRouterConfigurationPage(QtGui.QWidget, Ui_iosRouterConfigPageWidget):
             del settings["private_config"]
             del settings["image"]
 
+        if not node:
+            startup_config = self.uiStartupConfigLineEdit.text()
+            if startup_config != settings["startup_config"]:
+                if os.access(startup_config, os.R_OK):
+                    settings["startup_config"] = startup_config
+                else:
+                    QtGui.QMessageBox.critical(self, "Startup-config", "Cannot read the startup-config file")
+
+            private_config = self.uiPrivateConfigLineEdit.text()
+            if private_config != settings["private_config"]:
+                if os.access(private_config, os.R_OK):
+                    settings["private_config"] = private_config
+                else:
+                    QtGui.QMessageBox.critical(self, "Private-config", "Cannot read the private-config file")
+
         # get the platform and chassis if applicable
         platform = settings["platform"]
         if "chassis" in settings:
