@@ -21,11 +21,12 @@ Wizard for IOU devices.
 
 import os
 import sys
-import pkg_resources
 
 from gns3.qt import QtGui
 from gns3.node import Node
 from gns3.servers import Servers
+from gns3.utils.get_resource import get_resource
+from gns3.utils.get_default_base_config import get_default_base_config
 
 from ....settings import ENABLE_CLOUD
 from ..ui.iou_device_wizard_ui import Ui_IOUDeviceWizard
@@ -76,6 +77,9 @@ class IOUDeviceWizard(QtGui.QWizard, Ui_IOUDeviceWizard):
         if not ENABLE_CLOUD:
             self.uiCloudRadioButton.hide()
 
+        # location of the base config templates
+        self._base_iou_l2_config_template = get_resource(os.path.join("configs", "iou_l2_base_initial-config.txt"))
+        self._base_iou_l3_config_template = get_resource(os.path.join("configs", "iou_l3_base_initial-config.txt"))
 
     def _remoteServerToggledSlot(self, checked):
         """
@@ -169,28 +173,27 @@ class IOUDeviceWizard(QtGui.QWizard, Ui_IOUDeviceWizard):
 
         path = self.uiIOUImageLineEdit.text()
 
+        initial_config = ""
         if self.uiTypeComboBox.currentText() == "L2 image":
             # set the default L2 base initial-config
-            resource_name = "configs/iou_l2_base_initial-config.txt"
-            if hasattr(sys, "frozen") and os.path.isfile(resource_name):
-                initial_config = os.path.normpath(resource_name)
-            elif pkg_resources.resource_exists("gns3", resource_name):
-                iou_base_config_path = pkg_resources.resource_filename("gns3", resource_name)
-                initial_config = os.path.normpath(iou_base_config_path)
+            default_base_config = get_default_base_config(self._base_iou_l2_config_template)
+            if default_base_config:
+                initial_config = default_base_config
             default_symbol = ":/symbols/multilayer_switch.normal.svg"
             hover_symbol = ":/symbols/multilayer_switch.selected.svg"
             category = Node.switches
+            ethernet_adapters = 4
+            serial_adapters = 0
         else:
             # set the default L3 base initial-config
-            resource_name = "configs/iou_l3_base_initial-config.txt"
-            if hasattr(sys, "frozen") and os.path.isfile(resource_name):
-                initial_config = os.path.normpath(resource_name)
-            elif pkg_resources.resource_exists("gns3", resource_name):
-                iou_base_config_path = pkg_resources.resource_filename("gns3", resource_name)
-                initial_config = os.path.normpath(iou_base_config_path)
+            default_base_config = get_default_base_config(self._base_iou_l3_config_template)
+            if default_base_config:
+                initial_config = default_base_config
             default_symbol = ":/symbols/router.normal.svg"
             hover_symbol = ":/symbols/router.selected.svg"
             category = Node.routers
+            ethernet_adapters = 2
+            serial_adapters = 2
 
         if IOU.instance().settings()["use_local_server"] or self.uiLocalRadioButton.isChecked():
             server = "local"
@@ -208,6 +211,8 @@ class IOUDeviceWizard(QtGui.QWizard, Ui_IOUDeviceWizard):
             "path": path,
             "image": os.path.basename(path),
             "initial_config": initial_config,
+            "ethernet_adapters": ethernet_adapters,
+            "serial_adapters": serial_adapters,
             "default_symbol": default_symbol,
             "category": category,
             "hover_symbol": hover_symbol,
