@@ -57,24 +57,22 @@ DEFAULT_LOCAL_SERVER_PORT = 8000
 if sys.platform.startswith("win"):
     if "PROGRAMFILES(X86)" in os.environ:
         # windows 64-bit
-        program_files = os.environ["PROGRAMFILES(X86)"]
+        program_files = os.environ["PROGRAMFILES"]
+        program_files_x86 = os.environ["PROGRAMFILES(X86)"]
     else:
         # windows 32-bit
-        program_files = os.environ["PROGRAMFILES"]
+        program_files_x86 = program_files = os.environ["PROGRAMFILES"]
 
     PRECONFIGURED_TELNET_CONSOLE_COMMANDS = {'Putty (included with GNS3)': 'putty.exe -telnet %h %p -wt "%d" -gns3 5 -skin 4',
-                                             'SuperPutty': 'SuperPutty.exe -telnet "%h -P %p -wt \"%d\" -gns3 5 -skin 4"',
+                                             'SuperPutty (included with GNS3)': r'SuperPutty.exe -telnet "%h -P %p -wt \"%d\""',
                                              'SecureCRT': r'"{}\VanDyke Software\SecureCRT\SecureCRT.exe" /SCRIPT securecrt.vbs /ARG "%d" /T /TELNET %h %p'.format(program_files),
-                                             'TeraTerm Pro': r'"{}\teraterm\ttermpro.exe" /W="%d" /M="ttstart.macro" /T=1 %h %p'.format(program_files),
+                                             'TeraTerm Pro': r'"{}\teraterm\ttermpro.exe" /W="%d" /M="ttstart.macro" /T=1 %h %p'.format(program_files_x86),
                                              'Telnet': 'telnet %h %p',
-                                             'Xshell 4': r'"{}\NetSarang\Xshell 4\xshell.exe" -url telnet://%h:%p'.format(program_files),
-                                             'ZOC 6': r'"{}\ZOC6\zoc.exe" "/TELNET:%h:%p" /TABBED "/TITLE:%d"'.format(program_files)}
+                                             'Xshell 4': r'"{}\NetSarang\Xshell 4\xshell.exe" -url telnet://%h:%p'.format(program_files_x86),
+                                             'ZOC 6': r'"{}\ZOC6\zoc.exe" "/TELNET:%h:%p" /TABBED "/TITLE:%d"'.format(program_files_x86)}
 
     # default on Windows
-    if os.path.exists(os.getcwd() + os.sep + "SuperPutty.exe"):
-        DEFAULT_TELNET_CONSOLE_COMMAND = PRECONFIGURED_TELNET_CONSOLE_COMMANDS["SuperPutty"]
-    else:
-        DEFAULT_TELNET_CONSOLE_COMMAND = PRECONFIGURED_TELNET_CONSOLE_COMMANDS["Putty (included with GNS3)"]
+    DEFAULT_TELNET_CONSOLE_COMMAND = PRECONFIGURED_TELNET_CONSOLE_COMMANDS["Putty (included with GNS3)"]
 
 elif sys.platform.startswith("darwin"):
     # Mac OS X
@@ -134,7 +132,7 @@ else:
 if sys.platform.startswith("win"):
     # Windows
     PRECONFIGURED_SERIAL_CONSOLE_COMMANDS = {'Putty (included with GNS3)': 'putty.exe -serial %s -wt "%d [Local Console]" -gns3 5',
-                                             'SuperPutty': 'SuperPutty.exe -serial "%s -wt \"%d\" -gns3 5 -skin 4"'}
+                                             'SuperPutty': r'SuperPutty.exe -serial "%s -wt \"%d\""'}
 
     # default Windows serial console command
     if os.path.exists(os.getcwd() + os.sep + "SuperPutty.exe"):
@@ -208,6 +206,8 @@ GENERAL_SETTINGS = {
     "bring_console_to_front": True,
     "delay_console_all": 500,
     "default_local_news": False,
+    "hide_news_dock_widget": False,
+    "debug_level": 0,
 }
 
 GENERAL_SETTING_TYPES = {
@@ -226,6 +226,8 @@ GENERAL_SETTING_TYPES = {
     "bring_console_to_front": bool,
     "delay_console_all": int,
     "default_local_news": bool,
+    "hide_news_dock_widget": bool,
+    "debug_level": int,
 }
 
 GRAPHICS_VIEW_SETTINGS = {
