@@ -40,8 +40,10 @@ log = logging.getLogger(__name__)
 
 
 class TopologyInstance:
+
     def __init__(self, name, id, size_id, image_id, private_key, public_key,
                  host=None, port=None, ssl_ca=None, ssl_ca_file=None):
+
         # host, port, ssl_ca and ssl_ca_file are not known when the instance is created.
         # They will typically be set at a later point in time.
         self.name = name
@@ -86,6 +88,7 @@ class Topology(object):
         self._initialized_nodes = []
         self._resources_type = "local"
         self._instances = []
+        self._auto_start = False
 
     def addNode(self, node):
         """
@@ -267,7 +270,6 @@ class Topology(object):
         :param id: the instance id
         :return: a TopologyInstance object
         """
-
         for instance in self._instances:
             if instance.id == id:
                 return instance
@@ -424,6 +426,7 @@ class Topology(object):
                     "version": __version__,
                     "type": "topology",
                     "topology": {},
+                    "auto_start": False,
                     "resources_type": project_settings["project_type"],
                     }
 
@@ -435,6 +438,8 @@ class Topology(object):
         if self._nodes:
             topology_nodes = topology["topology"]["nodes"] = []
             for node in self._nodes:
+                if not node.initialized():
+                    continue
                 if node.server().id() not in servers:
                     servers[node.server().id()] = node.server()
                 log.info("saving node: {}".format(node.name()))
@@ -488,6 +493,9 @@ class Topology(object):
             log.warn("not a topology file")
             return
 
+        # auto start option
+        self._auto_start = topology.get("auto_start", False)
+
         # deactivate the unsaved state support
         main_window.ignoreUnsavedState(True)
         # trick: no matter what, reactivate the unsaved state support after 3 seconds
@@ -516,6 +524,8 @@ class Topology(object):
             for topology_server in servers:
                 if "local" in topology_server and topology_server["local"]:
                     self._servers[topology_server["id"]] = server_manager.localServer()
+                elif "cloud" in topology_server and topology_server["cloud"]:
+                    self._servers[topology_server["id"]] = server_manager.anyCloudServer()
                 else:
                     host = topology_server["host"]
                     port = topology_server["port"]
@@ -724,6 +734,10 @@ class Topology(object):
                     if source_port and destination_port:
                         view.addLink(source_node, source_port, destination_node, destination_port)
 
+        # Auto start
+        if self._auto_start and hasattr(node, "start"):
+            node.start()
+
     def _createPortLabel(self, node, label_info):
         """
         Creates a port label.
